import matplotlib.pyplot as plt
import media
import scambia
import MySQLdb as sql
import argparse


# per far funzionare su gitlab usare questi valori
# Host: mysql
# User: runner
# Password: Databasepss20/21 #noqa
# Database: assignment1
def get_im_from_db(indice, hostn):
    db = sql.connect(host=hostn, user="runner", passwd="Databasepss20/21", db="assignment1") # nosec
    #db = sql.connect(host="127.0.0.1", user="root", passwd=MYSQL_PASS, db=MYSQL_DB) # noqa
    cursor = db.cursor()
    percorso = "SELECT percorso FROM metadata WHERE id =" + str(indice)
    cursor.execute(percorso)
    # results = cursor.fetchall()
    results = cursor.fetchone()
    image = plt.imread(str(results[0]))
    return image


if __name__ == "__main__":
    parser = argparse.ArgumentParser(description='give db hostname')
    parser.add_argument('hostname', type=str, help='the hostname')
    args = parser.parse_args()

    im = get_im_from_db(2, args.hostname)

    array_medie = media.get_media(im)

    pos = array_medie.index(max(array_medie))

    new_im = scambia.scambia(im, pos)
    print("sto per stampare le immagini")
    plt.subplot(1, 2, 1)
    plt.imshow(im)
    plt.subplot(1, 2, 2)
    plt.imshow(new_im)
    plt.show()



import matplotlib.pyplot as plt
import numpy as np
import media
import scambia


def test_media():
    # verifico la prima proprietà della media, ovvero che la somma degli scarti di ciascun valore di x è nulla
    # sum(xi-M)=0
    # carico immagine su cui fare il test
    im = plt.imread('immagini/flower.jpg')

    im_red = im[:, :, 0]
    im_green = im[:, :, 1]
    im_blue = im[:, :, 2]

    array_medie = media.get_media(im)

    # canale del rosso
    s_r = 0
    for i in im_red:
        for j in i:
            ss_r = j - array_medie[0]
            s_r = s_r + ss_r

    # canale del verde
    s_g = 0
    for i in im_green:
        for j in i:
            ss_g = j - array_medie[1]
            s_g = s_g + ss_g

    # canale del blu
    s_b = 0
    for i in im_blue:
        for j in i:
            ss_b = j - array_medie[2]
            s_b = s_b + ss_b

    assert (s_r > -0.01 and s_r < 0.01) and (s_g > -0.01 and s_g < 0.01) and \
           (s_b > -0.01 and s_b < 0.01), "la somma degli scarti non è 0"


def test_scambia():
    # carico l' immagine su cui fare il test
    im = plt.imread('immagini/flower.jpg')

    # verifico che scambiando due volte gli stessi canali l' immagine risultante è la stessa di quella di partenza
    for i in range(3):
        new_im = scambia.scambia(scambia.scambia(im, i), i)
        assert np.allclose(new_im, im), "scambiando due volte gli stessi canali le immagini non sono uguali"


